@@ -159,12 +159,8 @@ function(object) {
 })
 
 
-summary.blavaan <- function(object, ...) {
-    bl.long.summary(object, ...)
-}
-
-bl.long.summary <- function(object,
-                 header       = TRUE,
+setMethod("summary", signature(object = "blavaan"),
+function(object, header       = TRUE,
                  fit.measures = FALSE,
                  estimates    = TRUE,
                  ci           = TRUE,
@@ -335,9 +331,7 @@ bl.long.summary <- function(object,
         print(PE, nd = nd)
     } # parameter estimates
 }
-
-setMethod("summary", "blavaan", summary.blavaan)
-
+)
 
 # NB not absolutely necessary, except for
 # bug in lavaan 0.5-23.1097
